Request class

Container for all possible ROS request parameters.

Constructors

Request({required String op, String? id, String? type, String? topic, dynamic msg, bool? latch, String? compression, int? throttleRate, int? queueLength, int? queueSize, String? service, Map<String, dynamic>? args, dynamic values, bool? result})
Request.decode(String raw)
factory
Request.fromJson(dynamic jsonData)
factory

Properties

args ↔ Map<String, dynamic>?
Arguments of the request (JSON).
getter/setter pair
compression ↔ String?
The type of compression to use, like 'png' or 'cbor'.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
ID to distinguish request or object operating on.
getter/setter pair
latch ↔ bool?
Latch the topic when publishing.
getter/setter pair
msg ↔ dynamic
Message object (generally JSON).
getter/setter pair
op ↔ String
Requested operation.
getter/setter pair
queueLength ↔ int?
The queue length at the bridge side used when subscribing.
getter/setter pair
queueSize ↔ int?
The queue created at the bridge side for republishing topics.
getter/setter pair
result ↔ bool?
Boolean value indicating the success of the operation.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
service ↔ String?
Service name operating on.
getter/setter pair
throttleRate ↔ int?
The rate (in ms between messages) at which to throttle the topic.
getter/setter pair
topic ↔ String?
Topic name operating on.
getter/setter pair
type ↔ String?
Message or service type.
getter/setter pair
values ↔ dynamic
Values returned from a request.
getter/setter pair

Methods

encode() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited